import Errors from './Errors';
import Request from './Request';
export declare enum FormMethods {
    POST = "post",
    PATCH = "patch",
    PUT = "put"
}
export interface FormConfig {
    resetAfterSend?: boolean;
    removeNullValues?: boolean;
    method?: FormMethods;
    request?: Request;
    url?: string | null;
}
export interface FormProperties {
    [key: string]: any;
}
export default class Form {
    [key: string]: any;
    private readonly originalData;
    private readonly config;
    errors: Errors;
    private request;
    private touchedFields;
    /**
     * Create a new Form instance.
     */
    constructor(data: FormProperties, config?: FormConfig);
    /**
     * Add a new field with value to the form.
     */
    addField(field: string, value: any): void;
    removeField(field: string): void;
    setUrl(url: string): Form;
    addTouchedField(field: string): void;
    getTouchedFields(): Array<string>;
    /**
     * Serialize the Form.
     */
    serialize(asString?: boolean): string | object;
    /**
     * Submit the form.
     */
    submit(url: string | null): Promise<any>;
    validate(url: string | null): Promise<any>;
    /**
     * Get FormData object.
     */
    getFormData(): FormData;
    /**
     * Reset the state of the form to the original state.
     */
    reset(): void;
    private getUrl;
    private send;
}
