"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
var Request = /** @class */ (function () {
    function Request(config) {
        var _this = this;
        if (config === void 0) { config = {}; }
        this.service = axios_1.default.create();
        this.config = config;
        this.service.defaults.withCredentials = this.config.withCredentials;
        this.service.defaults.headers.common['X-Requested-With'] = 'XMLHttpRequest';
        if (this.config.headers) {
            var headers_1 = this.config.headers;
            Object.keys(headers_1).forEach(function (key) {
                _this.service.defaults.headers.common[key] = headers_1[key];
            });
        }
        this.service.interceptors.response.use(function (response) {
            var _a;
            (_a = _this.config.successCallbacks) === null || _a === void 0 ? void 0 : _a.forEach(function (callback) {
                callback(response);
            });
            return response;
        }, function (error) {
            var _a, _b;
            // 419 error means that the CSRF token has timed out
            // in that case if the config autoRequestCsrfCookie is set to 'true',
            // we try to receive new token and retry the request.
            if (error.response) {
                var responseStatusCode_1 = error.response.status;
                if (responseStatusCode_1 === 419
                    && _this.config.autoRequestCsrfCookie
                    && typeof _this.config.csrfCookieUrl !== 'undefined') {
                    _this.get(_this.config.csrfCookieUrl)
                        .then(function () {
                        _this.service.request(error.config);
                    });
                }
                (_b = (_a = _this.config.errorCallbacks) === null || _a === void 0 ? void 0 : _a.find(function (callback) {
                    if (callback.errorCode === null) {
                        return true;
                    }
                    var callbackErrorCode = callback.errorCode;
                    if (!Array.isArray(callbackErrorCode)) {
                        callbackErrorCode = [callbackErrorCode];
                    }
                    return callbackErrorCode.includes(responseStatusCode_1);
                })) === null || _b === void 0 ? void 0 : _b.callback(error);
            }
            return Promise.reject(error);
        });
    }
    Request.mock = function (configs) {
        var service = Request.getInstance().service;
        // eslint-disable-next-line global-require
        var MockAdapter = require('axios-mock-adapter');
        var mock = new MockAdapter(service);
        configs.forEach(function (config) {
            mock.onAny(config.matcher, config.requestBody)
                .reply(config.statusCode, config.responseBody);
        });
        return Request.getInstance();
    };
    Request.getInstance = function () {
        if (!Request.instance) {
            Request.instance = new Request(Request.instanceConfig);
        }
        return Request.instance;
    };
    Request.setConfig = function (config) {
        Object.keys(config).forEach(function (key) {
            if (Object.prototype.hasOwnProperty.call(Request.instanceConfig, key)
                && Object.prototype.hasOwnProperty.call(config, key)) {
                // @ts-ignore
                Request.instanceConfig[key] = config[key];
            }
        });
    };
    Request.setHeader = function (name, value) {
        var headers = Request.instanceConfig.headers;
        if (headers) {
            headers[name] = value;
        }
        Request.instance = new Request(Request.instanceConfig);
    };
    Request.prototype.getConfig = function () {
        return this.config;
    };
    // eslint-disable-next-line max-len
    Request.prototype.get = function (url, config) {
        return this.service.get(url, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.post = function (url, data, config) {
        return this.service.post(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.patch = function (url, data, config) {
        return this.service.patch(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.put = function (url, data, config) {
        return this.service.put(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.delete = function (url, config) {
        return this.service.delete(url, config);
    };
    Request.instanceConfig = {
        autoRequestCsrfCookie: true,
        csrfCookieUrl: '/sanctum/csrf-cookie',
        errorCallbacks: [],
        successCallbacks: [],
        headers: {},
        withCredentials: true,
    };
    return Request;
}());
exports.default = Request;
//# sourceMappingURL=Request.js.map